MLHub Package
=============

Provides the ml command.

Also the Python mlhub pacakge and R mlhub package.

The python mlhub package is installed to pypi.

The R mlhub package is installed from github:

	sudo Rscript -e 'devtools::install_github("mlhubber/mlhub", quiet=TRUE)'

